@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: arg.c,v 1.33 96/02/21 09:18:21 abe Exp $";
+static char *rcsid = "$Id: arg.c,v 1.36 96/05/14 08:13:39 abe Exp $";
 #endif
 
 
@@ -180,7 +180,7 @@ ctrl_dcache(c)
 		if ((DCpathArg = (char *)malloc(len + 1)) == NULL) {
 			(void) fprintf(stderr,
 				"%s: no space for -D path: %s\n", Pn, c);
-			exit(1);
+			Exit(1);
 		}
 		(void) strcpy(DCpathArg, c);
 	}
@@ -211,7 +211,7 @@ enter_fd(f)
 	if ((fc = (char *)malloc(len)) == (char *)NULL) {
 	    (void) fprintf(stderr, "%s: no space for %d byte fd string: %s\n",
 		Pn, len, f);
-	    exit(1);
+	    Exit(1);
 	}
 	(void) strcpy(fc, f);
 /*
@@ -291,7 +291,7 @@ enter_id(ty, p)
 	default:
 		(void) fprintf(stderr,
 			"%s: enter_id \"%s\", invalid type: %d\n", Pn, p, ty);
-		exit(1);
+		Exit(1);
 	}
 /*
  * Convert and store the ID.
@@ -342,7 +342,7 @@ enter_id(ty, p)
 			    (void) fprintf(stderr,
 				"%s: no space for %d process%s IDs",
 				Pn, mx, (ty == PGRP) ? " group" : "");
-			    exit(1);
+			    Exit(1);
 			}
 		}
 		s[n++] = id;
@@ -394,8 +394,8 @@ enter_network_address(na)
 no_nwad_space:
 
 	    (void) fprintf(stderr,
-		"%s: no space for network address from \"%s\"\n", Pn, na);
-	    exit(1);
+		"%s: no space for network address from %s\n", Pn, na);
+	    Exit(1);
 	}
 	n->proto = NULL;
 	n->a[0] = n->a[1] = n->a[2] = n->a[3] = 0;
@@ -411,7 +411,7 @@ no_nwad_space:
 	    if ((l = wa - p)) {
 		if ((n->proto = (char *)malloc(l + 1)) == NULL) {
 		    (void) fprintf(stderr,
-			"%s: no space for protocol name from \"%s\"\n",
+			"%s: no space for protocol name from %s\n",
 			Pn, na);
 nwad_exit:
 		    if (n->proto)
@@ -423,6 +423,17 @@ nwad_exit:
 		}
 		(void) strncpy(n->proto, p, l);
 		n->proto[l] = '\0';
+	    /*
+	     * The protocol name should be "tcp" or "udp".
+	     */
+		if (strcasecmp(n->proto, "tcp") != 0
+		&&  strcasecmp(n->proto, "udp") != 0)
+		{
+			(void) fprintf(stderr,
+		    	    "%s: unknown protocol name (%s) in %s\n",
+			    Pn, n->proto, na);
+			goto nwad_exit;
+		}
 	    /*
 	     * Convert protocol name to lower case.
 	     */
@@ -442,7 +453,7 @@ nwad_exit:
 
 unacc_address:
 		(void) fprintf(stderr,
-		    "%s: unacceptable Internet address in \"%s\"\n", Pn, na);
+		    "%s: unacceptable Internet address in %s\n", Pn, na);
 		goto nwad_exit;
 	    }
 	    if (*wa < '0' || *wa > '9') {
@@ -454,14 +465,14 @@ unacc_address:
 		if ((l = p - wa)) {
 		    if ((hn = (char *)malloc(l + 1)) == NULL) {
 			fprintf(stderr,
-			    "%s: no space for host name from \"%s\"\n", Pn, na);
+			    "%s: no space for host name from %s\n", Pn, na);
 			goto nwad_exit;
 		    }
 		    (void) strncpy(hn, wa, l);
 		    hn[l] = '\0';
 		    if ((he = gethostbyname(hn)) == NULL) {
-			fprintf(stderr, "%s: unknown host name in \"%s\"\n",
-			    Pn, na);
+			fprintf(stderr, "%s: unknown host name (%s) in %s\n",
+			    Pn, hn, na);
 			goto nwad_exit;
 		    }
 		    ap = (unsigned char *)he->h_addr;
@@ -502,7 +513,7 @@ unacc_address:
 	if (*wa && (*wa != ':' || ! *(++wa))) {
 
 unacc_port:
-	    (void) fprintf(stderr, "%s: unacceptable port number in \"%s\"\n",
+	    (void) fprintf(stderr, "%s: unacceptable port number in %s\n",
 		Pn, na);
 	    goto nwad_exit;
 	}
@@ -513,13 +524,13 @@ unacc_port:
 	 * protocol name.
 	 */
 	    if (! n->proto) {
-		(void) fprintf(stderr, "%s: must specify protocol in \"%s\"\n",
+		(void) fprintf(stderr, "%s: must specify protocol in %s\n",
 		    Pn, na);
 		goto nwad_exit;
 	    }
 	    if ((se = getservbyname(wa, n->proto)) == NULL) {
 		(void) fprintf(stderr,
-		    "%s: unknown service \"%s\" for protocol %s in \"%s\"\n",
+		    "%s: unknown service (%s) for protocol %s in %s\n",
 		    Pn, wa, n->proto, na);
 		goto nwad_exit;
 	    }
@@ -543,7 +554,7 @@ unacc_port:
 	&&  n->a[0] == 0 && n->a[1] == 0 && n->a[2] == 0 && n->a[3] == 0
 	&&  n->port == -1) {
 	    (void) fprintf(stderr,
-		"%s: no Internet address specified in \"%s\"\n",
+		"%s: no Internet address specified in %s\n",
 		Pn, na);
 	    goto nwad_exit;
 	}
@@ -618,7 +629,8 @@ int
 enter_uid(u)
 	char *u;			/* User IDentifier string pointer */
 {
-	int err, i, nn;
+	int err, excl, i, j, nn;
+	MALLOC_S len;
 	char lnm[LOGINML];
 	struct passwd *pw;
 	char *s;
@@ -633,13 +645,17 @@ enter_uid(u)
 	/*
 	 * Assemble next User IDentifier.
 	 */
-		for (i = nn = uid = 0; *s && *s != ','; i++, s++) {
-			if (i >= LOGINML-1) {
+		for (i = j = nn = excl = uid = 0; *s && *s != ','; i++, s++) {
+			if (j >= LOGINML-1) {
 				(void) fprintf(stderr,
 					"%s: illegal UID in %s\n", Pn, u);
 				return(1);
 			}
-			lnm[i] = *s;
+			if (i == 0 && *s == '^') {
+				excl = 1;
+				continue;
+			}
+			lnm[j++] = *s;
 			if (nn)
 				continue;
 
@@ -656,7 +672,7 @@ enter_uid(u)
 		if (*s)
 			s++;
 		if (nn) {
-		       lnm[i] = '\0';
+		       lnm[j] = '\0';
 
 #if	defined(HASPWSTAYOPEN)
 			pw_stay_open();
@@ -690,30 +706,44 @@ enter_uid(u)
 	/*
 	 * Avoid entering duplicates.
 	 */
-		for (i = 0; i < Nuid; i++) {
-			if (uid == Suid[i])
-				break;
+		for (i = j = 0; i < Nuid; i++) {
+			if (uid != Suid[i].uid)
+				continue;
+			if (Suid[i].excl == excl) {
+				j = 1;
+				continue;
+			}
+			(void) fprintf(stderr,
+				"%s: UID %d has been included and excluded\n",
+				Pn, uid);
+			err = j = 1;
+			break;
 		}
-		if (i < Nuid)
+		if (j)
 			continue;
 	/*
 	 * Allocate space for User IDentifier.
 	 */
 		if (Nuid >= Mxuid) {
 			Mxuid += UIDINCR;
+			len = (MALLOC_S)(Mxuid * sizeof(struct seluid));
 			if (Suid == NULL)
-				Suid = (uid_t *)malloc((MALLOC_S)
-					(sizeof(uid_t) * Mxuid));
+				Suid = (struct seluid *)malloc(len);
 			else
-				Suid = (uid_t *)realloc((MALLOC_P *)Suid,
-					(MALLOC_S)(sizeof(uid_t) * Mxuid));
+				Suid = (struct seluid *)realloc(
+						(MALLOC_P *)Suid, len);
 			if (Suid == NULL) {
 				(void) fprintf(stderr, "%s: no space for UIDs",
 					Pn);
-				exit(1);
+				Exit(1);
 			}
 		}
-		Suid[Nuid++] = uid;
+		Suid[Nuid].uid = uid;
+		Suid[Nuid++].excl = excl;
+		if (excl)
+			Nuidexcl++;
+		else
+			Nuidincl++;
 	}
 	return(err);
 }
@@ -801,7 +831,7 @@ usage(xv, fh, version)
 	    (void) fprintf(stderr,
 		"Use the ``-h'' option to get more help information.\n");
 	    if (!fh)
-    		exit(xv);
+    		Exit(xv);
 	}
 	if (Fhelp) {
 	    (void) fprintf(stderr, "Defaults are enclosed in parentheses.");
@@ -899,7 +929,7 @@ usage(xv, fh, version)
 	    (void) fprintf(stderr, "  %-37.37s",
 		"-t     terse listing");
 	    (void) fprintf(stderr,
-		"-u s   select by user login/UID set\n");
+		"-u s   exclude(^)/select login/UID set\n");
 	    (void) fprintf(stderr, "  %-37.37s",
 		"-U     select Unix socket files");
 	    (void) fprintf(stderr,
@@ -945,7 +975,7 @@ usage(xv, fh, version)
 # if	defined(HASENVDC) || defined(HASPERSDC) || defined(HASSYSDC)
 	    cp = NULL;
 #  if	defined(HASENVDC)
-	    if (dx == -2 && (dx = dcpath(1)) >= 0)
+	    if (dx == -2 && (dx = dcpath(1, 0)) >= 0)
 		cp = DCpath[1];
 #  endif	/* defined(HASENVDC) */
 #  if	defined(HASSYSDC)
@@ -953,7 +983,7 @@ usage(xv, fh, version)
 		cp = HASSYSDC;
 #  endif	/* defined(HASSYSDC) */
 #  if	defined(HASPERSDC)
-	    if (!cp && dx != -1 && (dx = dcpath(1)) >= 0)
+	    if (!cp && dx != -1 && (dx = dcpath(1, 0)) >= 0)
 		cp = DCpath[3];
 #  endif	/* defined(HASPERSDC) */
 	    if (cp)
@@ -979,7 +1009,7 @@ usage(xv, fh, version)
 	 */
 	    (void) fprintf(stderr, "%s: device cache file read-only paths:\n",
 		Pn);
-	    if ((dx = dcpath(1)) < 0)
+	    if ((dx = dcpath(1, 0)) < 0)
 		(void) fprintf(stderr, "\tnone\n");
 	    else {
 		(void) fprintf(stderr, "\tNamed via -D: %s\n",
@@ -1014,7 +1044,7 @@ usage(xv, fh, version)
 # endif	/* defined(HASPERSDC) */
 	    }
 	    (void) fprintf(stderr, "%s: device cache file write paths:\n", Pn);
-	    if ((dx = dcpath(2)) < 0)
+	    if ((dx = dcpath(2, 0)) < 0)
 		(void) fprintf(stderr, "\tnone\n");
 	    else {
 		(void) fprintf(stderr, "\tNamed via -D: %s\n",
@@ -1083,5 +1113,5 @@ usage(xv, fh, version)
 		if ((cp = isnullstr(LSOF_SYSINFO)))
 			(void) fprintf(stderr, "\tsystem info: %s\n", cp);
 	}
-	exit(xv);
+	Exit(xv);
 }
