@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: dlsof.h,v 1.10 96/03/08 14:02:20 abe Exp $
+ * $Id: dlsof.h,v 1.11 96/05/13 08:04:44 abe Exp $
  */
 
 
@@ -235,6 +235,23 @@ typedef struct afs_lock afs_rwlock_t;
 # endif	/* defined(HAS_AFS) */
 
 
+# if	_AIXV>=4140
+/*
+ * Local clone information
+ */
+
+struct clone {
+	unsigned long ino;		/* inode number */
+	char *nm;			/* device name */
+	dev_t rdev;			/* device number */
+	struct clone *next;		/* next entry */
+};
+extern struct clone *Clone;
+extern int CloneMaj;
+extern int ClonePtc;
+#endif	/* _AIXV>=4140 */
+
+
 /*
  * Local vfs information
  */
