@@ -32,12 +32,22 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1995 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.9 96/01/11 16:41:58 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.11 96/04/05 09:51:53 abe Exp $";
 #endif
 
 
 #include "lsof.h"
 
+#if	PTXV<400
+#define	_INKERNEL
+#endif	/* PTXV<400 */
+
+#include <sys/ufsinode.h>
+
+#if	PTXV<400
+#undef	_INKERNEL
+#endif	/* PTXV<400 */
+
 
 #if	_PTXV>=400
 _PROTOTYPE(static void ent_fa,(caddr_t *a1, caddr_t *a2, char *d));
@@ -85,7 +95,7 @@ ent_fa(a1, a2, d)
 		(void) fprintf(stderr,
 			"%s: no space for fattach addresses at PID %d, FD %s\n",
 			Pn, Lp->pid, Lf->fd);
-		exit(1);
+		Exit(1);
 	}
 	(void) strcpy(cp, buf);
 	Lf->nma = cp;
@@ -195,13 +205,8 @@ void
 process_node(va)
 	caddr_t va;			/* vnode kernel space address */
 {
-
-#if	defined(HAS_CDFS)
-	struct cd_inode c;
-#endif	/* defined(HAS_CDFS) */
-
 	char *cp, dev_ch[32];
-	dev_t dev;
+	dev_t dev = 0;
 	int dl, j, k, l, pt, px;
 	struct l_dev *dp;
 	struct fifonode f;
@@ -257,7 +262,9 @@ read_vnode:
 /*
  * Determine the vnode type.
  */
-	if (Nl[X_FIFOOPS].n_value && (long)v.v_op == Nl[X_FIFOOPS].n_value)
+	if (Nl[X_UFSOPS].n_value && (long)v.v_op == Nl[X_UFSOPS].n_value)
+		Ntype = N_REGLR;
+	else if (Nl[X_FIFOOPS].n_value && (long)v.v_op == Nl[X_FIFOOPS].n_value)
 		Ntype = N_FIFO;
 
 #if	defined(HAS_NFS)
@@ -275,6 +282,12 @@ read_vnode:
 		Ntype = N_CDFS;
 #endif	/* defined(HAS_CDFS) */
 
+#if	defined(HAS_VXFS)
+	else if (Nl[X_VXFSOPS].n_value
+	     &&  (long)v.v_op == Nl[X_VXFSOPS].n_value)
+		Ntype = N_VXFS;
+#endif	/* defined(HAS_VXFS) */
+
 #if	_PTXV>=400
 	else if (Nl[X_NMOPS].n_value && (long)v.v_op == Nl[X_NMOPS].n_value) {
 		Ntype = N_NM;
@@ -303,6 +316,17 @@ read_vnode:
 	}
 #endif	/* _PTXV>=400 */
 
+	else {
+	
+	/*
+	 * The file system type is unknown.
+	 */
+		(void) sprintf(Namech,
+			"unknown file system type, v_op: %#x", v.v_op);
+		enter_nm(Namech);
+		return;
+	}
+
 #if	_PTXV>=400
 /*
  * If this node has a v_vfsmountedhere pointer, read it.  If it represents
@@ -325,20 +349,20 @@ read_vnode:
 	if (v.v_vfsp == NULL)
 		vfs = NULL;
 	else {
-	    if ((vfs = readvfs(v.v_vfsp)) == NULL) {
+	    if ((vfs = readvfs(&v)) == NULL) {
                 (void) sprintf(Namech, "bad vfs for %#x at %#x", va, v.v_vfsp);
                 enter_nm(Namech);
 		return;
 	    }
 	}
 /*
- * Read the cd_inode, fifonode, inode, rnode, or snode.
+ * Read the cd_inode, fifonode, inode, rnode, snode, or vx_inode.
  */
 	switch (Ntype) {
 
 #if	defined(HAS_CDFS)
 	case N_CDFS:
-		if (!v.v_data || kread((KA_T)v.v_data, (char *)&c, sizeof(c))) {
+		if (!v.v_data || read_cdnode(&v, vfs, &dev)) {
 			(void) sprintf(Namech,
 				"vnode at %#x: can't read cd_inode (%#x)",
 				va, v.v_data);
@@ -348,6 +372,18 @@ read_vnode:
 		break;
 #endif	/* defined(HAS_CDFS) */
 
+#if	defined(HAS_VXFS)
+	case N_VXFS:
+		if (!v.v_data || read_vxnode(&v, vfs, &dev)) {
+			(void) sprintf(Namech,
+				"vnode at %#x: can't read vx_inode (%#x)",
+				va, v.v_data);
+			enter_nm(Namech);
+			return;
+		}
+		break;
+#endif	/* defined(HAS_VXFS) */
+
 	case N_FIFO:
 		if (!v.v_data || kread((KA_T)v.v_data, (char *)&f, sizeof(f))) {
 			(void) sprintf(Namech,
@@ -414,7 +450,7 @@ read_vnode:
 		    }
 		    srv = 1;
 		    if (rv.v_data) {
-			if (readinode((struct inode *)v.v_data, &i) == 0) {
+			if (kread((KA_T)v.v_data, (char *)&i, sizeof(i)) == 0) {
 			    sin = 1;
 
 #if	defined(HASLFILEADD)
@@ -566,7 +602,7 @@ read_vnode:
 		break;
 	case N_REGLR:
 	default:
-		if (!v.v_data || readinode((struct inode *)v.v_data, &i)) {
+		if (!v.v_data || kread((KA_T)v.v_data, (char *)&i, sizeof(i))) {
 			(void) sprintf(Namech,
 				"vnode at %#x: can't read inode (%#x)",
 				va, v.v_data);
@@ -584,11 +620,12 @@ read_vnode:
 /*
  * Get device and type for printing.
  */
-	dev = 0;
 	switch(Ntype) {
 
 #if	defined(HAS_CDFS)
 	case N_CDFS:
+		/* dev is set in read_cdnode() */
+		break;
 #endif	/* defined(HAS_CDFS) */
 
 
@@ -612,6 +649,13 @@ read_vnode:
 		(void) sprintf(dev_ch, "0x%08x", va);
 		enter_dev_ch(dev_ch);
 		break;
+
+#if	defined(HAS_VXFS)
+	case N_VXFS:
+		/* dev is set in read_vxnode() */
+		break;
+#endif	/* defined(HAS_VXFS) */
+
 	case N_SPEC:
 		if (sop != (struct so_so *)NULL)
 			dev = so.lux_dev.addr.tu_addr.dev;
@@ -644,11 +688,17 @@ read_vnode:
 
 #if	defined(HAS_CDFS)
 	case N_CDFS:
-		Lf->inode = (unsigned long)c.iso_extent;
-		Lf->inp_ty = 1;
+		/* Lf->inode and Lf->inp_ty are set in read_cdnode() */
 		break;
 #endif	/* defined(HAS_CDFS) */
 
+#if	defined(HAS_VXFS)
+	case N_VXFS:
+		/* Lf->inode and Lf->inp_ty are set in read_vxnode() */
+		break;
+#endif	/* defined(HAS_VXFS) */
+
+
 	case N_FIFO:
 		break;
 
@@ -689,11 +739,17 @@ read_vnode:
 
 #if	defined(HAS_CDFS)
 		case N_CDFS:
-			Lf->sz = (unsigned long)c.i_size;
-			Lf->sz_def = 1;
+			/* Lf->sz and Lf->sz_def are set in read_cdnode() */
 			break;
 #endif	/* defined(HAS_CDFS) */
 
+#if	defined(HAS_VXFS)
+		case N_VXFS:
+			/* Lf->sz and Lf->sz_def are set in read_vxnode() */
+			break;
+#endif	/* defined(HAS_VXFS) */
+
+
 		case N_FIFO:
 
 #if	_PTXV<400
