@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1995 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.16 95/11/22 12:44:19 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.17 96/04/05 09:51:14 abe Exp $";
 #endif
 
 #include "lsof.h"
@@ -91,7 +91,7 @@ gather_proc_info()
 		(void) fprintf(stderr,
 		    "%s: no space for %d byte user structure buffer\n",
 		    Pn, MAXUSIZE * NBPC);
-		exit(1);
+		Exit(1);
 	    }
 	    u = (struct user *)ua;
 	}
@@ -102,7 +102,7 @@ gather_proc_info()
 	    if ((pb = (char *)malloc(sizeof(struct proc) * PROCBFRD)) == NULL) {
 		(void) fprintf(stderr, "%s: no space for %d proc structures\n",
 		    Pn, PROCBFRD);
-		exit(1);
+		Exit(1);
 	    }
 	}
 
@@ -235,7 +235,7 @@ get_cdevsw()
 	if ((Cdevsw = (char **)malloc(Cdevcnt * sizeof(char *))) == NULL) {
 		(void) fprintf(stderr, "%s: no space for %d cdevsw[] names\n",
 			Pn, Cdevcnt);
-		exit(1);
+		Exit(1);
 	}
 /*
  * Allocate temporary space for a copy of cdevsw[] and read it.
@@ -244,7 +244,7 @@ get_cdevsw()
 	if ((tmp = (struct cdevsw *)malloc(i)) == NULL) {
 		(void) fprintf(stderr, "%s: no space for %d cdevsw[] entries\n",
 			Pn, Cdevcnt);
-		exit(1);
+		Exit(1);
 	}
 	if (kread((KA_T)Nl[X_CDEVSW].n_value, (char *)tmp, i)) {
 		(void) free((FREE_P *)Cdevsw);
@@ -275,7 +275,7 @@ get_cdevsw()
 		    (void) fprintf(stderr,
 			"%s: no space for cdevsw[%d] name: %s\n",
 			Pn, i, buf);
-		    exit(1);
+		    Exit(1);
 		}
 		(void) strcpy(Cdevsw[i], buf);
 		if ( ! HaveCloneMajor && strcmp(buf, "clone") == 0) {
@@ -301,20 +301,20 @@ get_kernel_access()
  * See if the non-KMEM memory file is readable.
  */
 	if (Memory && !is_readable(Memory, 1))
-		exit(1);
+		Exit(1);
 /*
  * Open kernel memory access.
  */
 	if ((Kmem = open(Memory ? Memory : KMEM, O_RDONLY, 0)) < 0) {
 	    (void) fprintf(stderr, "%s: can't open %s: %s\n", Pn,
 		Memory ? Memory : KMEM, strerror(errno));
-	    exit(1);
+	    Exit(1);
 	}
 /*
  * See if the name list file is readable.
  */
 	if (Nmlst && !is_readable(Nmlst, 1))
-		exit(1);
+		Exit(1);
 /*
  * Access kernel symbols.
  */
@@ -322,7 +322,7 @@ get_kernel_access()
 	    (void) fprintf(stderr,
 		"%s: can't read kernel name list from %s\n",
 		Pn, Nmlst ? Nmlst : N_UNIX);
-	    exit(1);
+	    Exit(1);
 	}
 
 #if     defined(WILLDROPGID)
@@ -337,7 +337,7 @@ get_kernel_access()
  */
 	if ((Kp = Nl[X_PROC].n_value) == (long)NULL) {
 	    (void) fprintf(stderr, "%s: no proc table pointer\n", Pn);
-	    exit(1);
+	    Exit(1);
 	}
 
 #if	_SCOV<500
@@ -350,14 +350,14 @@ get_kernel_access()
 	    (void) fprintf(stderr,
 		"%s: can't read pregion count (%d) from 0x%#x\n",
 		Pn, Npp, Nl[X_PREGPP].n_value); 
-	    exit(1);
+	    Exit(1);
 	}
 	Prsz = (MALLOC_S)(Npp * sizeof(struct pregion));
 	if ((Pr = (struct pregion *)malloc(Prsz)) == NULL) {
 	    (void) fprintf(stderr,
 		"%s: can't allocate space for %d pregions\n",
 		Pn, Npp);
-	    exit(1);
+	    Exit(1);
 	}
 #endif	/* _SCOV< 500 */
 
@@ -369,7 +369,7 @@ get_kernel_access()
 	{
 	    (void) fprintf(stderr,
 		"%s: can't read system configuration info\n", Pn);
-	    exit(1);
+	    Exit(1);
 	}
 /*
  * Read system clock values -- Hz and lightning bolt timer.
@@ -434,7 +434,7 @@ get_kernel_access()
 	{
 	    (void) fprintf(stderr, "%s: no space for %d byte xdevmap table\n",
 		Pn, len);
-	    exit(1);
+	    Exit(1);
 	}
 	if (Nl[X_XDEV].n_value == (long)NULL
 	||  kread((KA_T)Nl[X_XDEV].n_value, (char *)Xdevmap, len))
@@ -560,7 +560,7 @@ process_text(prp)
 				(void) fprintf(stderr,
 					"%s: no txt ptr space, PID %d\n",
 					Pn, Lp->pid);
-				exit(1);
+				Exit(1);
 			}
 			Nn = 10;
 		} else if (j >= Nn) {
@@ -571,7 +571,7 @@ process_text(prp)
 				(void) fprintf(stderr,
 					"%s: no more txt ptr space, PID %d\n",
 					Pn, Lp->pid);
-				exit(1);
+				Exit(1);
 			}
 		}
 		Nc[j++] = na;
@@ -623,21 +623,21 @@ readfsinfo()
 	if ((Fsinfomax = sysfs(GETNFSTYP)) == -1) {
 		(void) fprintf(stderr, "%s: sysfs(GETNFSTYP) error: %s\n",
 			Pn, strerror(errno));
-		exit(1);
+		Exit(1);
 	} 
 	if (Fsinfomax == 0)
 		return;
 	if ((Fsinfo = (char **)malloc((MALLOC_S)(Fsinfomax * sizeof(char *))))
 	== NULL) {
 		(void) fprintf(stderr, "%s: no space for sysfs info\n", Pn);
-		exit(1);
+		Exit(1);
 	}
 	for (i = 1; i <= Fsinfomax; i++) {
 		if (sysfs(GETFSTYP, i, buf) == -1) {
 			(void) fprintf(stderr,
 				"%s: sysfs(GETFSTYP) error: %s\n",
 				Pn, strerror(errno));
-			exit(1);
+			Exit(1);
 		}
 		buf[FSTYPSZ] = '\0';
 		if ((Fsinfo[i-1] = (char *)malloc((MALLOC_S)(strlen(buf) + 1)))
@@ -645,7 +645,7 @@ readfsinfo()
 			(void) fprintf(stderr,
 				"%s: no space for file system entry %s\n",
 				Pn, buf);
-			exit(1);
+			Exit(1);
 		}
 		(void) strcpy(Fsinfo[i-1], buf);
 	}
@@ -785,7 +785,7 @@ DEV_enter(le, nm, nl, fs)
 		(void) fprintf(stderr,
 		    "%s: no more space for %d byte local name cache: %s\n",
 		    Pn, len, fs);
-		exit(1);
+		Exit(1);
 	    }
 	}
 	lc = &DEV_nc[DEV_csz];
@@ -838,7 +838,7 @@ DEV_nosp(len)
 	    (void) fprintf(stderr,
 		"%s: no space for %d byte local DEV name cache\n",
 		Pn, len);
-	exit(1);
+	Exit(1);
 }
 
 
@@ -1029,7 +1029,7 @@ ncache_load()
 		(void) fprintf(stderr,
 		    "%s: no space for %d DEV name cache hash pointers\n",
 		    Pn, DEV_nh + DEV_csz);
-	    exit(1);
+	    Exit(1);
 	}
 /*
  * Enter DEV_cache pointers in the hash table.  Look for entries with the
@@ -1387,7 +1387,7 @@ NFS_load()
 		(void) fprintf(stderr,
 		    "%s: no space for %d NFS name cache hash pointers\n",
 		    Pn, NFS_nh + NFS_csz);
-	    exit(1);
+	    Exit(1);
 	}
 /*
  * Enter NFS_cache pointers in the hash table.  Look for entries with the
@@ -1441,7 +1441,7 @@ NFS_nosp(len)
 	if (!Fwarn)
 	    (void) fprintf(stderr,
 		"%s: no space for %d byte local NFS name cache\n", Pn, len);
-	exit(1);
+	Exit(1);
 }
 
 
@@ -1508,7 +1508,7 @@ NFS_root(r)
 	    if (rc == (struct rnode **)NULL) {
 		(void) fprintf(stderr, "%s: no space for root rnode table\n",
 		    Pn);
-		exit(1);
+		Exit(1);
 	    }
 	}
 	rc[rnc++] = r;
