@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.26 96/03/09 14:51:25 abe Exp Locker: abe $";
+static char *rcsid = "$Id: dnode.c,v 1.29 96/05/20 07:49:45 abe Exp $";
 #endif
 
 
@@ -445,6 +445,12 @@ process_node(na)
 	int xs = 0;
 	int xt = 0;
 
+# if	defined(HASCACHEFS)
+	struct vattr at;
+	int ats;
+	struct cnode c;
+# endif	/* defined(HASCACHEFS) */
+
 # if	defined(HASPROCFS)
 	static long pgsz = -1L;
 	struct proc proc;
@@ -458,7 +464,7 @@ process_node(na)
 # endif	/* _IRIXV>=50200 */
 
 # if	_IRIXV>=60200
-	struct xfsnode xfs;
+	struct xfs_inode xfs;
 # endif	/* _IRIXV>=60200 */
 
 /*
@@ -489,27 +495,54 @@ process_node(na)
 	 */
 		fx = kv.vfs_fstype;
 		if (fx > 0 && fx <= Fsinfomax) {
-			if (strcmp(Fsinfo[fx-1], "fifofs") == 0)
+			if (strcmp(Fsinfo[fx-1], "efs") == 0)
+				Ntype = N_REGLR;
+			else if (strcmp(Fsinfo[fx-1], "fifofs") == 0)
 				Ntype = N_FIFO;
-			else if (strcmp(Fsinfo[fx-1], "nfs") == 0)
-			    Ntype = N_NFS;
+			else if (strcmp(Fsinfo[fx-1], "nfs") == 0
+			     ||  strcmp(Fsinfo[fx-1], "nfs3") == 0)
+				Ntype = N_NFS;
 			else if (strcmp(Fsinfo[fx-1], "socket") == 0) {
 				process_socket((caddr_t)v.v_data);
 				return;
 			} else if (strcmp(Fsinfo[fx-1], "pipefs") == 0)
 				Ntype = N_PIPE;
 
+# if	defined(HASCACHEFS)
+			else if (strcmp(Fsinfo[fx-1], "cachefs") == 0)
+				Ntype = N_CACHE;
+# endif	/* defined(HASCACHEFS) */
+
 # if	defined(HASPROCFS)
 			else if (strcmp(Fsinfo[fx-1], HASPROCFS) == 0)
 				Ntype = N_PROC;
 # endif	/* defined(HASPROCFS) */
 
 # if	_IRIXV>=60200
-			else if (strcmp(Fsinfo[fx-1], "xfs") == 0)
+			else if (strcmp(Fsinfo[fx-1], "xfs") == 0) {
+				Ntype = N_REGLR;
 				xt = N_XFS;
+			}
 # endif	/* _IRIXV>=060200 */
 
+			else {
+				(void) sprintf(Namech,
+					"unknown file system type (%d): %s",
+					fx, Fsinfo[fx-1]);
+				enter_nm(Namech);
+				return;
+			}
+		} else {
+			(void) sprintf(Namech, "unknown file system index: %s",
+				fx);
+			enter_nm(Namech);
+			return;
 		}
+	} else {
+		(void) sprintf(Namech,
+			"unusable virtual file system pointer: %#x", v.v_vfsp);
+		enter_nm(Namech);
+		return;
 	}
 	if (Ntype == N_REGLR) {
 		if (v.v_type == VFIFO)
@@ -536,9 +569,26 @@ process_node(na)
 	    }
 	}
 /*
- * Read the fifonode, inode, pipenode, rnode, snode, or xfsnode.
+ * Read the cnode, fifonode, inode, pipenode, rnode, snode, or xfsnode.
  */
 	switch (Ntype) {
+
+# if	defined(HASCACHEFS)
+	case N_CACHE:
+	    if (!v.v_data || kread((KA_T)v.v_data, (char *)&c, sizeof(c))) {
+		(void) sprintf(Namech,
+		    "vnode at %#x: can't read cnode at: %#x", na, v.v_data);
+		enter_nm(Namech);
+		return;
+	    }
+	    if (c.c_attr
+	    &&  kread((KA_T)c.c_attr, (char *)&at, sizeof(at)) == 0)
+		ats = 1;
+	    else
+		ats = 0;
+	    break;
+# endif	/* defined(HASCACHEFS) */
+
 	case N_FIFO:
 
 	/*
@@ -570,7 +620,7 @@ process_node(na)
 		if (xt == N_XFS) {
 		    if (kread((KA_T)rv.v_data, (char *)&xfs, sizeof(xfs))) {
 			(void) sprintf(Namech,
-			    "fifonode at %#x: can't read xfsnode at: %#x",
+			    "fifonode at %#x: can't read xfs_inode at: %#x",
 			    v.v_data, rv.v_data);
 			enter_nm(Namech);
 			return;
@@ -742,7 +792,7 @@ process_node(na)
 		    if (xt == N_XFS) {
 			if (kread((KA_T)rv.v_data, (char *)&xfs, sizeof(xfs))) {
 			    (void) sprintf(Namech,
-				"snode at %#x: can't read xfsnode at: %#x",
+				"snode at %#x: can't read xfs_inode at: %#x",
 				v.v_data, rv.v_data);
 			    enter_nm(Namech);
 			    return;
@@ -796,7 +846,7 @@ process_node(na)
 	    if (xt == N_XFS) {
 		if (kread((KA_T)v.v_data, (char *)&xfs, sizeof(xfs))) {
 		    (void) sprintf(Namech,
-			"vnode at %#x: can't read xfsnode at: %#x",
+			"vnode at %#x: can't read xfs_inode at: %#x",
 			na, v.v_data);
 		    enter_nm(Namech);
 		    return;
@@ -821,6 +871,10 @@ process_node(na)
  */
 	switch (Ntype) {
 
+# if	defined(HASCACHEFS)
+	case N_CACHE:
+# endif	/* defined(HASCACHEFS) */
+
 # if	defined(HASPROCFS)
 	case N_PROC:
 # endif
@@ -837,7 +891,7 @@ process_node(na)
 
 # if	_IRIXV>=60200
 		else if (xs)
-			dev = xfs.x_dev;
+			dev = xfs.i_dev;
 # endif	/* _IRIXV>=060200 */
 
 		else if (is)
@@ -852,6 +906,16 @@ process_node(na)
  * Obtain the inode number.
  */
 	switch (Ntype) {
+
+# if	defined(HASCACHEFS)
+	case N_CACHE:
+		if (ats) {
+			Lf->inode = (unsigned long)at.va_nodeid;
+			Lf->inp_ty = 1;
+		}
+		break;
+# endif	/* defined(HASCACHEFS) */
+
 	case N_NFS:
 		Lf->inode = (unsigned long)r.r_nfsattr.na_nodeid;
 		Lf->inp_ty = 1;
@@ -892,7 +956,7 @@ process_node(na)
 
 # if	_IRIXV>=60200
 		else if (xs) {
-			Lf->inode = xfs.x_ino;
+			Lf->inode = xfs.i_ino;
 			Lf->inp_ty = 1;
 		}
 # endif	/* _IRIXV>=060200 */
@@ -906,6 +970,14 @@ process_node(na)
 		Lf->off_def = 1;
 	else {
 		switch (Ntype) {
+
+# if	defined(HASCACHEFS)
+		case N_CACHE:
+			Lf->sz = (unsigned long)c.c_size;
+			Lf->sz_def = 1;
+			break;
+# endif	/* defined(HASCACHEFS) */
+
 		case N_FIFO:
 		case N_STREAM:
 			if (!Fsize)
@@ -939,7 +1011,7 @@ process_node(na)
 
 # if	_IRIXV>=60200
 				else if (xs) {
-					Lf->sz = xfs.x_size;
+					Lf->sz = xfs.i_d.di_size;
 					Lf->sz_def = 1;
 				}
 # endif	/* _IRIXV>=060200 */
