@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.21 96/03/09 14:51:37 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.23 96/04/05 09:50:35 abe Exp $";
 #endif
 
 #include "lsof.h"
@@ -129,7 +129,7 @@ gather_proc_info()
 			(void) fprintf(stderr,
 				"%s: no space for uarea and file pointers\n",
 				Pn);
-			exit(1);
+			Exit(1);
 		}
 		fp = (struct file **)(uaf + sizeof(struct user));
 		u = (struct user *)uaf;
@@ -150,7 +150,7 @@ gather_proc_info()
 		if ((Cwd = (char *)malloc(MAXPATHLEN)) == NULL) {
 			(void) fprintf(stderr,
 				"%s: no space for cwd buffer\n", Pn);
-			exit(1);
+			Exit(1);
 		}
 	}
 	if (Rtd == (char *)NULL) {
@@ -158,7 +158,7 @@ gather_proc_info()
 			(void) fprintf(stderr,
 				"%s: no space for root directory buffer\n",
 				Pn);
-			exit(1);
+			Exit(1);
 		}
 	}
 	*Cwd = *Rtd = '\0';
@@ -280,13 +280,13 @@ gather_proc_info()
 	 * Print information on the text file.
 	 */
 
-#if	_IRIXV<50300
+#if	_IRIXV<50300 || (_IRIXV>50300 && _IRIXV<60100)
 		if (p->p_region)
 			process_text(p->p_region);
-#else	/* _IRIXV>=50300 */
+#else	/* _IRIXV==50300 || _IRIXV>=60100 */
 		if (PREG_FIRST(p->p_region))
 			process_text(PREG_FIRST(p->p_region));
-#endif	/* _IRIXV<50300 */
+#endif	/* _IRIXV<50300 || (_IRIXV>50300 && _IRIXV<60100) */
 
 	/*
 	 * Save information on file descriptors.
@@ -307,11 +307,12 @@ gather_proc_info()
 		}
 #endif	/* _IRIXV<50101 */
 
-#if	_IRIXV>=50101 && _IRIXV<50300
+#if	(_IRIXV>=50101 && _IRIXV<50300) || (_IRIXV>50300 && _IRIXV<60100)
 	/*
-	 * Under IRIX 5.1.1 and below IRIX 5.3, the file pointers are stored
-	 * in dynamically-linked ufchunk structures, each containing NFPCHUNK
-	 * file pointers.  The first ufchunk structure is in the user area.
+	 * Under IRIX 5.1.1 and below IRIX 5.3, or above 5.3 and below 6.1,
+	 * the file pointers are stored in dynamically-linked ufchunk
+	 * structures, each containing NFPCHUNK file pointers.  The first
+	 * ufchunk structure is in the user area.
 	 */
 		for (i = 0, j = 0; i < u->u_nofiles; i++) {
 		    if (++j > NFPCHUNK) {
@@ -329,13 +330,13 @@ gather_proc_info()
 			    link_lfile();
 		    }
 		}
-#endif	/* _IRIXV>=50101 && _IRIXV<50300 */
+#endif	/* (_IRIXV>=50101 && _IRIXV<50300) || (_IRIXV>50300 && _IRIXV<60100) */
 
-#if	_IRIXV>=50300
+#if	_IRIXV==50300 || _IRIXV>=60100
 	/*
-	 * Under IRIX 5.3 and above, the file pointers are stored in
+	 * Under IRIX 5.3 and 6.1 and above, the file pointers are stored in
 	 * dynamically-linked ufchunk structures, each containing NFPCHUNK
-	 * file pointers.  The first urchunk structure is addressed via the
+	 * file pointers.  The first ufchunk structure is addressed via the
 	 * u_flist pointer in the user structure.
 	 */
 		for (uc.uf_next = u->u_flist, i = 0, j = NFPCHUNK;
@@ -357,7 +358,7 @@ gather_proc_info()
 			    link_lfile();
 		    }
 		}
-#endif	/* _IRIXV>=50300 */
+#endif	/* _IRIXV==50300 || _IRIXV>=60100 */
 
 	/*
 	 * Examine results.
@@ -392,7 +393,7 @@ get_kernel_access()
  * See if the non-KMEM memory file is readable.
  */
 	if (Memory && !is_readable(Memory, 1))
-		exit(1);
+		Exit(1);
 #endif	/* defined(WILLDROPGID) */
 
 /*
@@ -401,7 +402,7 @@ get_kernel_access()
 	if ((Kmem = open(Memory ? Memory : KMEM, O_RDONLY, 0)) < 0) {
 	    (void) fprintf(stderr, "%s: can't open %s: %s\n", Pn,
 		Memory ? Memory : KMEM, strerror(errno));
-	    exit(1);
+	    Exit(1);
 	}	
 
 #if	defined(WILLDROPGID)
@@ -415,7 +416,7 @@ get_kernel_access()
  * See if the name list file is readable.
  */
 	if (Nmlst && !is_readable(Nmlst, 1))
-		exit(1);
+		Exit(1);
 #endif	/* defined(WILLDROPGID) */
 
 /*
@@ -425,7 +426,7 @@ get_kernel_access()
 	    (void) fprintf(stderr,
 		"%s: can't read kernel name list from %s\n",
 		Pn, Nmlst ? Nmlst : N_UNIX);
-	    exit(1);
+	    Exit(1);
 	}
 /*
  * Set process table and var structure addresses.
@@ -488,14 +489,14 @@ get_kernel_access()
 	if (no_var)
 	    (void) fprintf(stderr, "%s: can't get var struct address\n", Pn);
 	if (no_proc || no_var)
-	    exit(1);
+	    Exit(1);
 /*
  * Read var structure.
  */
 	if (kread(kvar, (char *)&Var, sizeof(Var))) {
 	    (void) fprintf(stderr, "%s: can't read var struct at %#x\n",
 		Pn, kvar);
-	    exit(1);
+	    Exit(1);
 	}
 }
 
@@ -554,13 +555,13 @@ process_text(prp)
 /*
  * Follow the virtual address space pregion structure chain.
  */
-#if	_IRIXV<50300
+#if	_IRIXV<50300 || (_IRIXV>50300 && _IRIXV<60100)
 	for (i = lm = 0; prp; prp = p.p_forw, lm++)
-#else	/* _IRIXV>=50300 */
+#else	/* _IRIXV==50300 || _IRIXV>=60100 */
 	for (i = lm = 0;
 	     prp; 
 	     prp = (preg_t *)p.p_avlnode.avl_nextino, lm++)
-#endif	/* _IRIXV<50300 */
+#endif	/* _IRIXV<50300 || (_IRIXV>50300 && _IRIXV<60100) */
 
 	{
 
@@ -607,7 +608,7 @@ process_text(prp)
 				(void) fprintf(stderr,
 					"%s: no txt ptr space, PID %d\n",
 					Pn, Lp->pid);
-				exit(1);
+				Exit(1);
 			}
 			Nn = 10;
 		} else if (i >= Nn) {
@@ -618,7 +619,7 @@ process_text(prp)
 				(void) fprintf(stderr,
 					"%s: no more txt ptr space, PID %d\n",
 					Pn, Lp->pid);
-				exit(1);
+				Exit(1);
 			}
 		}
 		Ndc[i++] = na;
@@ -670,21 +671,21 @@ readfsinfo()
 	if ((Fsinfomax = sysfs(GETNFSTYP)) == -1) {
 		(void) fprintf(stderr, "%s: sysfs(GETNFSTYP) error: %s\n",
 			Pn, strerror(errno));
-		exit(1);
+		Exit(1);
 	} 
 	if (Fsinfomax == 0)
 		return;
 	if ((Fsinfo = (char **)malloc((MALLOC_S)(Fsinfomax * sizeof(char *))))
 	== NULL) {
 		(void) fprintf(stderr, "%s: no space for sysfs info\n", Pn);
-		exit(1);
+		Exit(1);
 	}
 	for (i = 1; i <= Fsinfomax; i++) {
 		if (sysfs(GETFSTYP, i, buf) == -1) {
 			(void) fprintf(stderr,
 				"%s: sysfs(GETFSTYP) error: %s\n",
 				Pn, strerror(errno));
-			exit(1);
+			Exit(1);
 		}
 		buf[FSTYPSZ] = '\0';
 		if ((Fsinfo[i-1] = (char *)malloc((MALLOC_S)(strlen(buf) + 1)))
@@ -692,7 +693,7 @@ readfsinfo()
 			(void) fprintf(stderr,
 				"%s: no space for file system entry %s\n",
 				Pn, buf);
-			exit(1);
+			Exit(1);
 		}
 		(void) strcpy(Fsinfo[i-1], buf);
 	}
@@ -711,7 +712,7 @@ readfsinfo()
 		(void) fprintf(stderr,
 			"%s: nfstyp value (%d) error, kernel = %#x\n",
 			Pn, Nfstyp, Nl[X_NFSTYP].n_value);
-		exit(1);
+		Exit(1);
 	}
 	len = (MALLOC_S)(Nfstyp * sizeof(struct fsinfo));
 	if (Nl[X_FSINFO].n_value == NULL
@@ -720,7 +721,7 @@ readfsinfo()
 		(void) fprintf(stderr,
 			"%s: fstyp read error, length = %d, kernel = %#x\n",
 			Pn, len, Nl[X_FSINFO].n_value);
-		exit(1);
+		Exit(1);
 	}
 /*
  * Get the file system names.
@@ -730,13 +731,13 @@ readfsinfo()
 		if ((cp = malloc(FSNAMEL)) == NULL) {
 		    (void) fprintf(stderr,
 			"%s: no space for file system name[%d]\n", Pn, i);
-		    exit(1);
+		    Exit(1);
 		}
 		if (kread((KA_T)Fsinfo[i].fs_name, cp, FSNAMEL)) {
 		    (void) fprintf(stderr,
 			"%s: can't read file system name[i] from %#x\n",
 			Pn, i, Fsinfo[i].fs_name);
-		    exit(1);
+		    Exit(1);
 		}
 		cp[FSNAMEL - 1] = '\0';
 		Fsinfo[i].fs_name = cp;
