@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.34 96/03/08 14:04:46 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.39 96/04/05 09:49:35 abe Exp $";
 #endif
 
 
@@ -49,6 +49,7 @@ _PROTOTYPE(static int read_ndn,(caddr_t na, caddr_t da, struct door_node *d));
 _PROTOTYPE(static int read_nfn,(caddr_t na, caddr_t fa, struct fifonode *f));
 _PROTOTYPE(static int read_nhn,(caddr_t na, caddr_t ha, struct hsnode *h));
 _PROTOTYPE(static int read_nin,(caddr_t na, caddr_t ia, struct inode *i));
+_PROTOTYPE(static int read_nmn,(caddr_t na, caddr_t ia, struct mvfsnode *m));
 _PROTOTYPE(static int read_npn,(caddr_t na, caddr_t pa, struct pcnode *p));
 _PROTOTYPE(static int read_nrn,(caddr_t na, caddr_t ra, struct rnode *r));
 _PROTOTYPE(static int read_nsn,(caddr_t na, caddr_t sa, struct snode *s));
@@ -99,7 +100,7 @@ ent_fa(a1, a2, d)
 		(void) fprintf(stderr,
 			"%s: no space for fattach addresses at PID %d, FD %s\n",
 			Pn, Lp->pid, Lf->fd);
-		exit(1);
+		Exit(1);
 	}
 	(void) strcpy(cp, buf);
 	Lf->nma = cp;
@@ -266,6 +267,7 @@ process_node(va)
 	struct inode i;
 	struct vfs kv;
 	struct vfs *la = NULL;
+	struct mvfsnode m;
 	int ni = 0;
 	struct pcnode pc;
 	struct rnode r;
@@ -348,7 +350,7 @@ process_node(va)
 #endif	/* defined(HAS_AFS) */
 
 				);
-			exit(1);
+			Exit(1);
 		}
 	}
 	if (readvnode((caddr_t)va, v)) {
@@ -393,14 +395,28 @@ vfs_read_error:
 /*
  * Determine the Solaris vnode type.
  */
-	if ((Ntype = vop2ty(v)) < 0)
-		Ntype = N_REGLR;
-	vty = Ntype;
-	if (v->v_type == VFIFO)
+	if ((Ntype = vop2ty(v)) < 0) {
+		if (v->v_type == VFIFO) {
+			vty = N_REGLR;
 			Ntype = N_FIFO;
-	else if (vs) {
-		Ntype = vty = N_STREAM;
-		Lf->is_stream = 1;
+		} else if (vs) {
+			Ntype = vty = N_STREAM;
+			Lf->is_stream = 1;
+		}
+		if (Ntype < 0) {
+			(void) sprintf(Namech,
+				"unknown file system type, v_op: %#x", v->v_op);
+			enter_nm(Namech);
+			return;
+		}
+	} else {
+		vty = Ntype;
+		if (v->v_type == VFIFO) {
+			Ntype = N_FIFO;
+		} else if (vs) {
+			Ntype = vty = N_STREAM;
+			Lf->is_stream = 1;
+		}
 	}
 /*
  * See if another Solaris node has fattach'ed to this node.
@@ -465,13 +481,19 @@ vfs_read_error:
  * Determine the non-Solaris vnode type.
  */
 	if ((Ntype = vop2ty(v)) < 0) {
+		vty = N_REGLR;
 		if (v->v_type == VFIFO)
 			Ntype = N_FIFO;
 		else if (v->v_type == VCHR && !v->v_vfsp && vs) {
 			Ntype = N_STREAM;
 			Lf->is_stream = 1;
-		} else
-			Ntype = N_REGLR;
+		}
+		if (Ntype < 0) {
+			(void) sprintf(Namech,
+				"unknown file system type, v_op: %#x", v->v_op);
+			enter_nm(Namech);
+			return;
+		}
 	}
 /*
  * See if this non-Solaris node is served by _spec_vnodeops.
@@ -601,6 +623,10 @@ vfs_read_error:
 		break;
 #endif	defined(X_DOOR_OPS)
 
+	case N_MVFS:
+		if (read_nmn(va, v->v_data, &m))
+			return;
+		break;
 	case N_NFS:
 		if (read_nrn(va, v->v_data, &r))
 			return;
@@ -757,8 +783,13 @@ vfs_read_error:
 #endif	/* defined(solaris) */
 
 				vty = N_STREAM;
-			else
-				vty = N_REGLR;
+			else {
+				(void) sprintf(Namech,
+				    "unknown file system type, v_op: %#x",
+				    v->v_op);
+				enter_nm(Namech);
+				return;
+			}
 		}
 		if (Ntype == N_NM || Ntype == N_AFS)
 			Ntype = vty;
@@ -794,6 +825,10 @@ vfs_read_error:
 			if (read_nhn(va, v->v_data, &h))
 				return;
 			break;
+		case N_MVFS:
+			if (read_nmn(va, v->v_data, &m))
+				return;
+			break;
 		case N_NFS:
 			if (read_nrn(va, v->v_data, &r))
 				return;
@@ -872,6 +907,14 @@ vfs_read_error:
 		break;
 #endif	/* defined(X_DOOR_OPS) */
 
+	case N_MVFS:
+		if (vfs)
+		    dev = vfs->dev;
+		else {
+		    dev = 0;
+		    dev_def = 0;
+		}
+		break;
 	case N_NFS:
 		dev = r.r_attr.va_fsid;
 		break;
@@ -973,6 +1016,10 @@ vfs_read_error:
 		Lf->inp_ty = 1;
 		break;
 
+	case N_MVFS:
+		Lf->inode = (unsigned long)m.m_ino;
+		Lf->inp_ty = 1;
+		break;
 	case N_NFS:
 		Lf->inode = (unsigned long)r.r_attr.va_nodeid;
 		Lf->inp_ty = 1;
@@ -1081,6 +1128,9 @@ vfs_read_error:
 			if (!Fsize)
 				Lf->off_def = 1;
 			break;
+		case N_MVFS:
+			/* The location of file size isn't known. */
+			break;
 		case N_NFS:
 
 			if ((type == VCHR || type == VBLK) && !Fsize)
@@ -1555,6 +1605,27 @@ read_nnn(na, nna, nn)
 #endif	/* defined(solaris) */
 
 
+/*
+ * read_nmn() - read node's mvfsnode
+ */
+
+static int
+read_nmn(na, ma, m)
+	caddr_t na;			/* containing node's address */
+	caddr_t ma;			/* kernel mvfsnode address */
+	struct mvfsnode *m;		/* mvfsnode receiver */
+{
+	if (!ma
+	||  kread((KA_T)ma, (char *)m, sizeof(struct mvfsnode))) {
+		(void) sprintf(Namech,
+			"node at %#x: can't read mvfsnode: %#x", na, ma);
+		enter_nm(Namech);
+		return(1);
+	}
+	return(0);
+}
+
+
 #if	defined(HASPROCFS)
 /*
  * read_npi() - read node's /proc file system information
@@ -1884,6 +1955,11 @@ vop2ty(vp)
 
 	if (!vp->v_op)
 		return(-1);
+	if ((Nl[X_UFS_OPS].n_value &&
+	    (unsigned long)vp->v_op == Nl[X_UFS_OPS].n_value)
+	||  (Nl[X_SPEC_OPS].n_value &&
+	     (unsigned long)vp->v_op == Nl[X_SPEC_OPS].n_value))
+		return(N_REGLR);
 	if (Nl[X_NFS_OPS].n_value
 	&& (unsigned long)vp->v_op == Nl[X_NFS_OPS].n_value)
 		return(N_NFS);
@@ -1902,6 +1978,12 @@ vop2ty(vp)
 	     &&   (unsigned long)vp->v_op == Nl[X_PC_FOPS].n_value))
 		return(N_PCFS);
 
+#if	defined(X_MVFS_OPS)
+	else if (Nl[X_MVFS_OPS].n_value &&
+	     (unsigned long)vp->v_op == Nl[X_MVFS_OPS].n_value)
+		return(N_MVFS);
+#endif	/* defined(X_MVFS_OPS) */
+
 #if	defined(X_CACHE_OPS)
 	else if (Nl[X_CACHE_OPS].n_value
 	     && (unsigned long)vp->v_op == Nl[X_CACHE_OPS].n_value)
