@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.22 96/02/21 08:10:43 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.23 96/04/05 09:49:38 abe Exp $";
 #endif
 
 #include "lsof.h"
@@ -96,7 +96,7 @@ close_kvm()
 		return;
 	if (kvm_close(Kd) != 0) {
 		(void) fprintf(stderr, "%s: kvm_close failed\n", Pn);
-		exit(1);
+		Exit(1);
 	}
 	Kd = NULL;
 }
@@ -322,7 +322,7 @@ gather_proc_info()
 					(void) fprintf(stderr,
 						"%s: PID %d, malloc file[]\n",
 						Pn, Lp->pid);
-					exit(1);
+					Exit(1);
 				}
 			} else if (nf > xnf) {
 				xnf = nf;
@@ -332,7 +332,7 @@ gather_proc_info()
 					(void) fprintf(stderr,
 						"%s: PID %d, realloc file[]\n",
 						Pn, Lp->pid);
-					exit(1);
+					Exit(1);
 				}
 			}
 			if (kread((KA_T)u->u_ofile, (char *)xuf, (int)ui))
@@ -385,7 +385,7 @@ get_kernel_access()
  * Get kernel symbols.
  */
 	if (Nmlst && !is_readable(Nmlst, 1))
-		exit(1);
+		Exit(1);
 
 #if	defined(HAS_AFS)
 	if (!Nmlst) {
@@ -401,7 +401,7 @@ get_kernel_access()
 			(void) fprintf(stderr,
 				"%s: no space (%d) for Nl[] copy\n",
 				Pn, NLSIZE);
-			exit(1);
+			Exit(1);
 		}
 
 # if	defined(solaris)
@@ -416,7 +416,7 @@ get_kernel_access()
 	if (nlist(Nmlst ? Nmlst : N_UNIX, Nl) < 0) {
 		(void) fprintf(stderr, "%s: can't read namelist from %s\n",
 			Pn, Nmlst ? Nmlst : N_UNIX);
-		exit(1);
+		Exit(1);
 	}
 
 #if	defined(HAS_AFS)
@@ -461,7 +461,7 @@ get_kernel_access()
  * See if the non-KMEM memory file is readable.
  */
 	if (Memory && !is_readable(Memory, 1))
-		exit(1);
+		Exit(1);
 #endif	/* defined(WILLDROPGID) */
 
 /*
@@ -485,7 +485,7 @@ get_kernel_access()
 	||  kread((KA_T)Nl[X_KERNELBASE].n_value, (char *)&Kb, sizeof(Kb))) {
 		(void) fprintf(stderr, "%s: can't read %s from %#lx\n", Pn,
 			Nl[X_KERNELBASE].n_name, Nl[X_KERNELBASE].n_value);
-		exit(1);
+		Exit(1);
 	}
 # endif	/* solaris >=20500 */
 /*
@@ -542,12 +542,12 @@ initialize()
  */
 	if ((Cwd = (char *)malloc(MAXPATHLEN)) == NULL) {
 		(void) fprintf(stderr, "%s: no space for cwd buffer\n", Pn);
-		exit(1);
+		Exit(1);
 	}
 	if ((Rtd = (char *)malloc(MAXPATHLEN)) == NULL) {
 		(void) fprintf(stderr,
 			"%s: no space for root directory buffer\n", Pn);
-		exit(1);
+		Exit(1);
 	}
 	*Cwd = *Rtd = '\0';
 #endif	/* solaris */
@@ -607,7 +607,7 @@ open_kvm()
 			(void) fprintf(stderr,
 				"%s: can't set effective GID to %d: %s\n",
 				Pn, Savedgid, strerror(errno));
-			exit(1);
+			Exit(1);
 		}
 		Setgid = 1;
 	}
@@ -620,7 +620,7 @@ open_kvm()
 			Nmlst ? Nmlst : "default",
 			Memory  ? Memory  : "default",
 			strerror(errno));
-		exit(1);
+		Exit(1);
 	}
 
 #if	defined(WILLDROPGID)
@@ -745,21 +745,21 @@ readfsinfo()
 	if ((Fsinfomax = sysfs(GETNFSTYP)) == -1) {
 		(void) fprintf(stderr, "%s: sysfs(GETNFSTYP) error: %s\n",
 			Pn, strerror(errno));
-		exit(1);
+		Exit(1);
 	} 
 	if (Fsinfomax == 0)
 		return;
 	if ((Fsinfo = (char **)malloc((MALLOC_S)(Fsinfomax * sizeof(char *))))
 	== NULL) {
 		(void) fprintf(stderr, "%s: no space for sysfs info\n", Pn);
-		exit(1);
+		Exit(1);
 	}
 	for (i = 1; i <= Fsinfomax; i++) {
 		if (sysfs(GETFSTYP, i, buf) == -1) {
 			(void) fprintf(stderr,
 				"%s: sysfs(GETFSTYP) error: %s\n",
 				Pn, strerror(errno));
-			exit(1);
+			Exit(1);
 		}
 		if (buf[0] == '\0') {
 			Fsinfo[i-1] = "";
@@ -771,7 +771,7 @@ readfsinfo()
 			(void) fprintf(stderr,
 				"%s: no space for file system entry %s\n",
 				Pn, buf);
-			exit(1);
+			Exit(1);
 		}
 		(void) strcpy(Fsinfo[i-1], buf);
 
@@ -816,7 +816,7 @@ read_proc()
 		len = (sz * sizeof(struct proc));
 		if ((P = (struct proc *)malloc(len)) == (struct proc *)NULL) {
 		    (void) fprintf(stderr, "%s: no proc table space\n", Pn);
-		    exit(1);
+		    Exit(1);
 		}
 
 #if	defined(solaris)
@@ -827,12 +827,12 @@ read_proc()
 		if (Fpgrp) {
 		    if ((Pgrp = (int *)malloc(len)) == (int *)NULL) {
 			(void) fprintf(stderr, "%s: no PGRP table space\n", Pn);
-			exit(1);
+			Exit(1);
 		    }
 		}
 		if ((Pid = (int *)malloc(len)) == (int *)NULL) {
 		    (void) fprintf(stderr, "%s: no PID table space\n", Pn);
-		    exit(1);
+		    Exit(1);
 		}
 #endif	/* defined(solaris) */
 
@@ -845,7 +845,7 @@ read_proc()
 	    if (kvm_setproc(Kd) != 0) {
 		(void) fprintf(stderr, "%s: kvm_setproc: %s\n", Pn,
 		    strerror(errno));
-		exit(1);
+		Exit(1);
 	    }
 	/*
 	 * Accumulate proc structures.
@@ -880,7 +880,7 @@ read_proc()
 		    == NULL) {
 			(void) fprintf(stderr,
 			    "%s: no more (%d) proc space\n", Pn, sz);
-			exit(1);
+			Exit(1);
 		    }
 
 #if	defined(solaris)
@@ -893,14 +893,14 @@ read_proc()
 			== NULL) {
 			    (void) fprintf(stderr,
 				"%s: no more (%d) PGRP space\n", Pn, sz);
-			    exit(1);
+			    Exit(1);
 			}
 		    }
 		    if ((Pid = (int *)realloc((MALLOC_P *)Pid, len))
 		    == NULL) {
 			(void) fprintf(stderr,
 			    "%s: no more (%d) PID space\n", Pn, sz);
-			exit(1);
+			Exit(1);
 		    }
 #endif	/* defined(solaris) */
 
@@ -937,7 +937,7 @@ read_proc()
  */
 	if (try >= PROCTRYLM) {
 	    (void) fprintf(stderr, "%s: can't read proc table\n", Pn);
-	    exit(1);
+	    Exit(1);
 	}
 	if (Np < sz && !RptTm) {
 
@@ -949,7 +949,7 @@ read_proc()
 	    if ((P = (struct proc *)realloc((MALLOC_P *)P, len)) == NULL) {
 		(void) fprintf(stderr, "%s: can't reduce proc table to %d\n",
 		    Pn, Np);
-		exit(1);
+		Exit(1);
 	    }
 
 #if	defined(solaris)
@@ -962,13 +962,13 @@ read_proc()
 		if ((Pgrp = (int *)realloc((MALLOC_P *)Pgrp, len)) == NULL) {
 		    (void) fprintf(stderr,
 			"%s: can't reduce PGRP table to %d\n", Pn, Np);
-		    exit(1);
+		    Exit(1);
 		}
 	    }
 	    if ((Pid = (int *)realloc((MALLOC_P *)Pid, len)) == NULL) {
 		(void) fprintf(stderr,
 		    "%s: can't reduce PID table to %d\n", Pn, Np);
-		exit(1);
+		Exit(1);
 	    }
 #endif	/* defined(solaris) */
 
