@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dstore.c,v 1.10 96/02/21 08:10:05 abe Exp $";
+static char *rcsid = "$Id: dstore.c,v 1.12 96/03/26 15:22:07 abe Exp $";
 #endif
 
 
@@ -97,6 +97,7 @@ struct nlist Nl[] = {
 	{ "fifo_vnodeops"	},
 	{ "hsfs_vnodeops"	},
 	{ "lo_vnodeops"		},
+	{ "mvfs_vnodeops"	},
 	{ "ncache"		},
 	{ "ncsize"		},
 	{ "nfs_vnodeops"	},
@@ -109,6 +110,7 @@ struct nlist Nl[] = {
 	{ "segvn_ops"		},
 	{ "spec_vnodeops"	},
 	{ "tmp_vnodeops"	},
+	{ "ufs_vnodeops"	},
 
 # if	solaris>=20500
 	{ "door_vnodeops"	},
@@ -131,6 +133,7 @@ struct nlist Nl[] = {
 	{ "_segvn_ops"		},
 	{ "_spec_vnodeops"	},
 	{ "_tmp_vnodeops"	},
+	{ "_ufs_vnodeops"	},
 # endif	/* defined(solaris) */
 
 	{ "" }
