@@ -31,7 +31,7 @@
 
 
 /*
- * $Id: lsof.h,v 1.39 96/03/09 14:52:28 abe Exp $
+ * $Id: lsof.h,v 1.41 96/04/18 10:25:33 abe Exp $
  */
 
 
@@ -83,17 +83,18 @@ extern int optind;
 #define N_HSFS		9		/* High Sierra node */
 #define N_LOFS		10		/* loopback node */
 #define N_MPC		11		/* multiplexed device node */
-#define N_NFS		12		/* NFS node */
-#define N_NM		13		/* named file system node */
-#define N_PCFS		14		/* PC file system node */
-#define N_PIPE		15		/* pipe device node */
-#define	N_PROC		16		/* /proc node */
-#define	N_SPEC		17		/* spec_vnodeops node */
-#define N_STREAM	18		/* stream node */
-#define N_TMP		19		/* tmpfs node */
-#define	N_UFS		20		/* Unix file system node */
-#define	N_VXFS		21		/* Veritas file system node */
-#define	N_XFS		22		/* XFS node */
+#define	N_MVFS		12		/* multi-volume file system node (?) */
+#define N_NFS		13		/* NFS node */
+#define N_NM		14		/* named file system node */
+#define N_PCFS		15		/* PC file system node */
+#define N_PIPE		16		/* pipe device node */
+#define	N_PROC		17		/* /proc node */
+#define	N_SPEC		18		/* spec_vnodeops node */
+#define N_STREAM	19		/* stream node */
+#define N_TMP		20		/* tmpfs node */
+#define	N_UFS		21		/* Unix file system node */
+#define	N_VXFS		22		/* Veritas file system node */
+#define	N_XFS		23		/* XFS node */
 #define	RPTTM		15		/* default repeat seconds */
 #define	RTD		" rtd"		/* root directory fd name */
 #define TMLIMIT		15		/* readlink() & stat() timeout sec */
@@ -141,6 +142,11 @@ struct afsnode {			/* AFS pseudo-node structure */
  * Global storage definitions (including their structure definitions)
  */
 
+struct seluid {
+	uid_t uid;			/* User ID */
+	int excl;			/* excluded state */
+};
+
 struct str_lst {
 	char *str;			/* string */
 	int len;			/* string length */
@@ -301,6 +307,8 @@ extern int Npid;
 extern int Npuns;
 extern int Ntype;
 extern int Nuid;
+extern int Nuidexcl;
+extern int Nuidincl;
 
 struct nwad {
 	char *proto;				/* protocol */
@@ -342,7 +350,7 @@ extern int Setuidroot;
 extern struct sfile *Sfile;
 extern int *Spgrp;
 extern int *Spid;
-extern uid_t *Suid;
+extern struct seluid *Suid;
 extern char Terminator;
 extern int TmLimit;
 
