@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: print.c,v 1.21 95/10/19 14:09:35 abe Exp $";
+static char *rcsid = "$Id: print.c,v 1.22 96/04/05 10:02:41 abe Exp $";
 #endif
 
 
@@ -137,7 +137,7 @@ gethostnm(ia)
 	if ((np = (char *)malloc((MALLOC_S)(strlen(hn) + 1))) == NULL) {
 		(void) fprintf(stderr, "%s: no space for host name: %s\n",
 			Pn, hn);
-		exit(1);
+		Exit(1);
 	}
 	(void) strcpy(np, hn);
 /*
@@ -154,7 +154,7 @@ gethostnm(ia)
 		if (hc == NULL) {
 			(void) fprintf(stderr, "%s: no space for host cache\n",
 				Pn);
-			exit(1);
+			Exit(1);
 		}
 	}
 	hc[hcx].addr[0] = u[0];
@@ -206,7 +206,7 @@ iporttab()
 		    "%s: no space for %s port %d cache name: %s\n", Pn,
 		    ty ? "UDP" : "TCP", p, se->s_name);
 		(void) endservent();
-		exit(1);
+		Exit(1);
 	    }
 	    (void) strcpy(np, se->s_name);
 	/*
@@ -225,7 +225,7 @@ iporttab()
 			"%s: no space for %s port table\n", Pn,
 			ty ? "UDP" : "TCP");
 		    (void) endservent();
-		    exit(1);
+		    Exit(1);
 		}
 	    }
 	/*
@@ -248,7 +248,7 @@ iporttab()
 		(void) fprintf(stderr,
 		    "%s: can't reduce %s port table size\n",
 		    ty ? "UDP" : "TCP", Pn);
-		exit(1);
+		Exit(1);
 	    }
 	    Npt[ty] = i[ty];
 	}
@@ -290,7 +290,7 @@ iuidcache(np)
 		Uc = (struct uidcache *)malloc(len);
 	if (Uc == NULL) {
 		(void) fprintf(stderr, "%s: no space for UID cache\n", Pn);
-		exit(1);
+		Exit(1);
 	}
 	while (i < Nuc) {
 		Uc[i++].nm[0] = '\0';
