@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: store.c,v 1.20 95/10/19 14:09:17 abe Exp $";
+static char *rcsid = "$Id: store.c,v 1.21 96/04/18 10:26:25 abe Exp $";
 #endif
 
 
@@ -187,6 +187,8 @@ int Npid = 0;			/* -p option count */
 int Npuns;			/* number of unselected PIDs (starts at Npid) */
 int Ntype;			/* node type (see N_* symbols) */
 int Nuid = 0;			/* -u option count */
+int Nuidexcl = 0;		/* -u option count of UIDs excluded */
+int Nuidincl = 0;		/* -u option count of UIDs included */
 struct nwad *Nwad = NULL;	/* list of network addresses */
 struct lfile *Plf = NULL;	/* previous local file structure */
 char *Pn;			/* program name */
@@ -208,6 +210,6 @@ int Setuidroot = 0;		/* setuid-root state */
 struct sfile *Sfile = NULL;	/* chain of files to search for */
 int *Spgrp = NULL;		/* process group IDs to search for */
 int *Spid = NULL;		/* Process IDs to search for */
-uid_t *Suid = NULL;		/* User IDs to search for */
+struct seluid *Suid = NULL;	/* User IDs to include or exclude */
 char Terminator = '\n';		/* output field terminator */
 int TmLimit = TMLIMIT;		/* Readlink() and stat() timeout (seconds) */
